@@ -19,7 +19,15 @@ from .webhook_response import WebhookResponse
 
 
 class AsyncWebhookClient:
-    logger = logging.getLogger(__name__)
+    url: str
+    timeout: int
+    ssl: Optional[SSLContext]
+    proxy: Optional[str]
+    session: Optional[ClientSession]
+    trust_env_in_session: bool
+    auth: Optional[BasicAuth]
+    default_headers: Dict[str, str]
+    logger: logging.Logger
 
     def __init__(
         self,
@@ -33,6 +41,7 @@ class AsyncWebhookClient:
         default_headers: Optional[Dict[str, str]] = None,
         user_agent_prefix: Optional[str] = None,
         user_agent_suffix: Optional[str] = None,
+        logger: Optional[logging.Logger] = None,
     ):
         """API client for Incoming Webhooks and response_url
         :param url: a complete URL to send data (e.g., https://hooks.slack.com/XXX)
@@ -45,6 +54,7 @@ class AsyncWebhookClient:
         :param default_headers: request headers to add to all requests
         :param user_agent_prefix: prefix for User-Agent header value
         :param user_agent_suffix: suffix for User-Agent header value
+        :param logger: custom logger
         """
         self.url = url
         self.timeout = timeout
@@ -57,6 +67,7 @@ class AsyncWebhookClient:
         self.default_headers["User-Agent"] = get_user_agent(
             user_agent_prefix, user_agent_suffix
         )
+        self.logger = logger if logger is not None else logging.getLogger(__name__)
 
     async def send(
         self,
@@ -65,6 +76,8 @@ class AsyncWebhookClient:
         attachments: Optional[Sequence[Union[Dict[str, Any], Attachment]]] = None,
         blocks: Optional[Sequence[Union[Dict[str, Any], Block]]] = None,
         response_type: Optional[str] = None,
+        replace_original: Optional[bool] = None,
+        delete_original: Optional[bool] = None,
         headers: Optional[Dict[str, str]] = None,
     ) -> WebhookResponse:
         """Performs a Slack API request and returns the result.
@@ -72,15 +85,21 @@ class AsyncWebhookClient:
         :param attachments: a collection of attachments
         :param blocks: a collection of Block Kit UI components
         :param response_type: the type of message (either 'in_channel' or 'ephemeral')
+        :param replace_original: True if you use this option for response_url requests
+        :param delete_original: True if you use this option for response_url requests
         :param headers: request headers to append only for this request
         :return: API response
         """
         return await self.send_dict(
+            # It's fine to have None value elements here
+            # because _build_body() filters them out when constructing the actual body data
             body={
                 "text": text,
                 "attachments": attachments,
                 "blocks": blocks,
                 "response_type": response_type,
+                "replace_original": replace_original,
+                "delete_original": delete_original,
             },
             headers=headers,
         )
